@@ -25,8 +25,7 @@ x=Wg*s;                      % rotates data to generate mixtures
 %  'kernel','hermite','p',3, 'sig',1.5,'kap',.0001,'polish',1,'restarts',2);
 
 % ONE UNIT CONTRAST FUNCTION - HERMITE KERNEL  
-Wcca=kernel_ica(x,'ncomp',m,'contrast','kgv', ...
-   'sig',1,'kap',.01,'polish',1,'restarts',2);
+Wcca=kernel_ica(x);
 
 
 sestimate=Wcca*x;
